# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V36
700
701
768
771
772
773
774
775
776
777
779
780
785
786
1024
1328
7296
7307
7467
7468
7544
7545
7672
7673
11744
11776
11843
11844
42560
42656
65070
65072
122928
122990
123023
123024
END
