+{
   locale_version => 1.31,
   entry => <<'ENTRY', # for DUCET v13.0.0
0451      ; [.23C0.0020.0002] # CYRILLIC SMALL LETTER IO
0435 0308 ; [.23C0.0020.0002] # CYRILLIC SMALL LETTER IO
0401      ; [.23C0.0020.0008] # CYRILLIC CAPITAL LETTER IO
0415 0308 ; [.23C0.0020.0008] # CYRILLIC CAPITAL LETTER IO
045E      ; [.2483.0020.0002] # CYRILLIC SMALL LETTER SHORT U
0443 0306 ; [.2483.0020.0002] # CYRILLIC SMALL LETTER SHORT U
040E      ; [.2483.0020.0008] # CYRILLIC CAPITAL LETTER SHORT U
0423 0306 ; [.2483.0020.0008] # CYRILLIC CAPITAL LETTER SHORT U
ENTRY
};
